@@ -1,4 +1,4 @@
-branch <- "cran/v0.16.1"
+branch <- "cran/v0.16.2"
 torch_version <- "2.7.1"
 
 #' Install Torch
@@ -74,41 +74,79 @@ torch_install_path <- function(check_writable = FALSE) {
 
 .torch_can_load <- NULL
 #' Verifies if torch is installed
-#'
+#' @importFrom callr r
+#' @importFrom cli cli_warn cli_inform
 #' @export
 torch_is_installed <- function() {
-  if (!lib_is_installed("lantern", torch_install_path())) {
+
+  install_path <- torch_install_path()
+
+  if (!lib_is_installed("lantern", install_path)) {
     return(FALSE)
   }
   
-  if(!lib_is_installed("torch", torch_install_path())) {
+  if(!lib_is_installed("torch", install_path)) {
     return(FALSE)
   }
-    
-  if (is.null(.torch_can_load) && Sys.getenv("TORCH_VERIFY_LOAD", "TRUE") == "TRUE") {
-    .torch_can_load <<- tryCatch({
-      callr::r(function() {
-        torch::torch_tensor(1)
-        TRUE
-      }, env = c(TORCH_VERIFY_LOAD = "FALSE"))
-    }, error = function(err) {
-      cli::cli_warn(c(
-        "Torch libraries are installed but loading them caused a segfault.",
-        "Please reinstall torch with {.code install_torch(reinstall = TRUE)}",
-        "You can disable this check by setting {.envvar TORCH_VERIFY_LOAD} to {.val FALSE}",
-        conditionMessage(err)
-      ))
-      FALSE
-    })
-  } else {
-    # In this case, we don't check further and just assume it can load
-    # so that we don't repeat the check every time
+
+  should_verify <- Sys.getenv("TORCH_VERIFY_LOAD", "TRUE") == "TRUE"
+
+  if (!should_verify) {
+    # if we should not verify, we just return TRUE here
     return(TRUE)
   }
 
+  # already verified, short circuit
+  if (is.logical(.torch_can_load)) {
+    return(.torch_can_load)
+  }
+
+  # verify if torch can be loaded
+  .torch_can_load <<- tryCatch({
+    out <- suppressWarnings(system2(
+      rscript_exe(),
+      args = c(
+        "-e",
+        "'torch::torch_tensor(1); TRUE'"
+      ),
+      stderr = TRUE,
+      stdout = TRUE,
+      env = c(
+        paste0("TORCH_HOME='", as.character(install_path), "'"),
+        "TORCH_VERIFY_LOAD=no" # avoid infinite recursion
+      )
+    ))
+
+    if (attr(out, "status") %||% 0L != 0L) {
+      stop(paste(out, collapse = "\n"))
+    }
+
+    TRUE
+  }, error = function(err) {
+    cli_inform(c(
+      "Torch libraries are installed but loading them was unsuccessful.",
+      "Please reinstall torch with {.code install_torch(reinstall = TRUE)}",
+      "You can disable this check by setting {.envvar TORCH_VERIFY_LOAD} to {.val FALSE}",
+      "Torch libraries installed in: {.path {install_path}}.",
+      if (interactive()) conditionMessage(err) else ""
+    ))
+
+    FALSE
+  })
+  
+  # return the result of the verification
   .torch_can_load
 }
 
+rscript_exe <- function() {
+  file.path(
+    R.home("bin"),
+    if (is_windows()) "Rscript.exe" else "Rscript"
+  )
+}
+
+is_windows <- function() identical(.Platform$OS.type, "windows")
+
 install_lib <- function(libname, url, reinstall = FALSE) {
   inst_path <- torch_install_path(check_writable = TRUE)
   installer_message(c(
