@@ -63,10 +63,10 @@ test_that("Multihead attention works", {
   x <- torch_randn(1,1,2)
   out <- attn1(x, x, x)
   
-  expect_equal_to_r(out[[1]][1,1,], c(0.0736, -0.0599), tol = 1e-4)
-  expect_equal_to_r(out[[2]][1,1,], c(1), tol = 1e-4)
-  expect_equal_to_r(attn1$in_proj_weight[1,], c(-0.1782,  0.4406), tol = 1e-4)
-  expect_equal_to_r(attn1$out_proj$weight[1,], c(0.3643, -0.3121), tol = 1e-4)
+  expect_equal_to_r(out[[1]][1,1,], c(0.0736, -0.0599), tolerance = 1e-4)
+  expect_equal_to_r(out[[2]][1,1,], c(1), tolerance = 1e-4)
+  expect_equal_to_r(attn1$in_proj_weight[1,], c(-0.1782,  0.4406), tolerance = 1e-4)
+  expect_equal_to_r(attn1$out_proj$weight[1,], c(0.3643, -0.3121), tolerance = 1e-4)
   
   # raise error when embed_dim is not divisible by num_heads.
   expect_error(nn_multihead_attention(embed_dim = 512, num_heads = 10), regexp="divisible")
